/*
 *  Kylin security execute control and Box module（模块，包功能介绍）
 *
 *  This file contains the definitions needed for Kylin security exectl
 *  functions
 *
 *  Authors:  songchuanfei <songchuanfei@kylinos.cn>
 *  Authors:  huanfuxi <huanfuxi@kylinos.cn>
 *  Authors:  mengyuan <mengyuan@kylinos.cn>
 *
 *  Copyright (C) 2017,Tianjin KYLIN Information Technology Co., Ltd.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the
 *  Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 */
#ifndef KYSECURITY_INCLUDE_H
#define KYSECURITY_INCLUDE_H

#include <sys/types.h>

#define IDENTIFY_OFFSET			6
#define PROTECT_OFFSET			4

#define SECADM_COMMAND			(0x01 << IDENTIFY_OFFSET)
#define AUDADM_COMMAND			(0x02 << IDENTIFY_OFFSET)
#define SYSADM_COMMAND			(0x03 << IDENTIFY_OFFSET)

#define KYSEC_INTEGRITY_PROTECT		(0x01 << PROTECT_OFFSET)
#define KYSEC_INTEGRITY_CHECK		(0x02 << PROTECT_OFFSET)

#define EXECTL_UNKNOWN			0x0			// 'unknown'
#define EXECTL_ORIGINAL			0x1			// 'original'
//#define EXECTL_ORIGINAL_CONFINED	0x2			// 'original'
#define EXECTL_VERIFIED			0x3			// 'verified'
#define EXECTL_KYSOFT			0x4			// 'kysoft'
//#define EXECTL_PRELINK		0x5			// 'prelink'
//#define EXECTL_PRELINK_OUT		0x6			// 'prelink_out'
//#define EXECTL_INTERPRET		0x7			// 'interpret'
//#define EXECTL_INTERPRET_OUT		0x8			// 'interpret_out'
#define EXECTL_TRUSTED			0x9			// 'trusted'
#define EXECTL_PARENT			0xa			// 'parent'
#define EXECTL_SCRIPT			0xb

#define EXECTL_INVALID			0xc			// =(max exectl sid + 1)

#define EXECTL_ORIGINAL_ALWAYS	EXECTL_ORIGINAL
#define EXECTL_VERIFIED_KYSOFT	EXECTL_KYSOFT
#define EXECTL_TRUSTED_READ	EXECTL_TRUSTED

/*
 * 00		01		0000
 * identify bit	protect bit	exec bit
 */

#define EXECTL_MASK		0xf
#define IDENTIFY_MASK		(0x3 << IDENTIFY_OFFSET)
#define PROTECT_MASK		(0x3 << PROTECT_OFFSET)

#ifndef XATTR_SECURITY_PREFIX
#define XATTR_SECURITY_PREFIX "security."
#endif

#define XATTR_KYSEC_SUFFIX "kysec"
#define XATTR_EXECTL_SUFFIX "exectl"
#define XATTR_NAME_KYSEC XATTR_SECURITY_PREFIX XATTR_KYSEC_SUFFIX
#define XATTR_NAME_EXECTL XATTR_SECURITY_PREFIX XATTR_EXECTL_SUFFIX

#define INTEGRITY_PROTECTED(sid)		(sid & PROTECT_MASK & KYSEC_INTEGRITY_PROTECT)
#define VERIFY_NEEDED(sid)			(sid & PROTECT_MASK & KYSEC_INTEGRITY_CHECK)

#define EXECTL_LABEL(sid)			(sid & EXECTL_MASK)
#define IDENTIFY_LABEL(sid)			(sid & IDENTIFY_MASK)

#define NEW_EXECTL_LABEL(sid, exectl_sid)	((sid & (~EXECTL_MASK)) | exectl_sid)


typedef unsigned char kysec_sid_t;

#endif
